[frogr] Use xdg-open instead of gnome-open. It was about time!



commit 932d7d601e284ddac38aa7efca84ed8410163f87
Author: Mario Sanchez Prada <msanchez gnome org>
Date:   Tue Nov 24 12:10:59 2015 +0000

    Use xdg-open instead of gnome-open. It was about time!

 NEWS             |    1 +
 src/frogr-util.c |    6 +++---
 2 files changed, 4 insertions(+), 3 deletions(-)
---
diff --git a/NEWS b/NEWS
index d1ed0c5..e81df88 100644
--- a/NEWS
+++ b/NEWS
@@ -1,6 +1,7 @@
 0.12 (??)
 =========
 
+  * Use xdg-open instead of gnome-open as a fallback plan to open URIs.
   * Use a GtkMessageDialog for the "Uploading pictures" dialog.
 
 
diff --git a/src/frogr-util.c b/src/frogr-util.c
index 913823c..12439e9 100644
--- a/src/frogr-util.c
+++ b/src/frogr-util.c
@@ -157,17 +157,17 @@ _open_uris_with_app_info (GList *uris_list, GAppInfo *app_info)
 
   if (!app_info || !g_app_info_launch_uris (app_info, uris_list, NULL, &error))
     {
       /* The default app didn't succeed, so try 'gnome-open' / 'open' */
       gchar *command = NULL;
       gchar *uris = NULL;
 
       uris = _get_uris_string_from_list (uris_list);
 
 #ifdef PLATFORM_MAC
       /* In MacOSX use 'open' instead of 'gnome-open' */
       command = g_strdup_printf ("open %s", uris);
 #else
-      command = g_strdup_printf ("gnome-open %s", uris);
+      command = g_strdup_printf ("xdg-open %s", uris);
 #endif
       _spawn_command (command);
 
@@ -157,17 +157,17 @@ _open_uris_with_app_info (GList *uris_list, GAppInfo *app_info)
   if (!app_info || !g_app_info_launch_uris (app_info, uris_list, NULL, &error))
     {
-      /* The default app didn't succeed, so try 'gnome-open' / 'open' */
+      /* The default app didn't succeed, so try 'xdg-open' / 'open' */
       gchar *command = NULL;
       gchar *uris = NULL;
@@ -157,17 +157,17 @@ _open_uris_with_app_info (GList *uris_list, GAppInfo *app_info)
 
 #ifdef PLATFORM_MAC
-      /* In MacOSX use 'open' instead of 'gnome-open' */
+      /* In MacOSX use 'open' instead of 'xdg-open' */
       command = g_strdup_printf ("open %s", uris);
 #else


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]